@@ -2,12 +2,15 @@ from tkdev import *
 from tkdev.devdemo import DevAppBar_Demo, DevDrag_Demo, DevMenuBar_Demo, DevPopupWindow_Demo, DevStatusBar_Demo, DevSubWindow_Demo
 
 
-class devdemo(tk.Tk):
+class devdemo(DevWindow):
     def __init__(self):
         super(devdemo, self).__init__()
-        self.title("tkdev demos")
+        from sv_ttk import use_dark_theme
+        self.mica()
+        self.title("")
         self.geometry("760x440")
 
+        use_dark_theme()
         self.paned = ttk.PanedWindow(self, orient=tk.HORIZONTAL, height=3)
 
         self.choices_frame = tk.Frame(self)
@@ -67,6 +70,7 @@ class devdemo(tk.Tk):
                 import tkinter.ttk as ttk
 
                 root = dev.DevToplevel()
+                root.mica()
                 root.geometry("300x350")
                 statusbar = dev.DevStatusBar(root, default_text="状态栏 | ")
                 root.statusbar(statusbar)
